local function make(tagger)
	local widget = {}

	-- Create tag tagindicators
	-- We're using flex.vertical and flex.horizontal layouts because the grid
	--  layout doesn't expand things properly.
	widget.tagindicators = {}
	widget.tagindicator = wibox.widget {
		homogeneous   = true,
		spacing       = beautiful.dpi(2),
		min_cols_size = 10,
		min_rows_size = 10,
		layout        = wibox.layout.grid
	}

	local tmp_row
	for r=1, tagger.rows do
		for c=1, tagger.cols do
			widget.tagindicators[(c + (tagger.cols * (r - 1)))] = wibox.widget {
				checked = false,
				border_width = beautiful.dpi(2),
				paddings = beautiful.dpi(3),
				color = beautiful.color.bar.active,
				border_color = beautiful.color.bar.inactive,
				widget = wibox.widget.checkbox
			}

			-- Calculate checkbox size limit
			local cbox_maxsize = beautiful.dpi(config.core.bar_height)
			cbox_maxsize = cbox_maxsize - (2 * beautiful.dpi(config.core.bar_margin))
			cbox_maxsize = cbox_maxsize - (tagger.rows - 1)*(beautiful.dpi(widget.tagindicator.spacing))

			if ((config.core.bar_position == "bottom") or (config.core.bar_position == "top")) then
				cbox_maxsize = cbox_maxsize / tagger.rows
			else
				cbox_maxsize = cbox_maxsize / tagger.cols
			end

			widget.tagindicator:add_widget_at(
				-- The constraint container is VERY necessary here!
				-- Otherwise, the checkboxes will fill all the height that is available to them.
				wibox.container.constraint(
					widget.tagindicators[(c + (tagger.cols * (r - 1)))],
					"exact", cbox_maxsize, cbox_maxsize
				), r, c)
		end
	end

	widget.widget = wibox.widget {
		widget.tagindicator,
		layout = wibox.container.background
	}

	-- Change background when mouse is over widget
	widget.widget:connect_signal("mouse::enter", function(result)
		widget.widget.bg = beautiful.color.bar.hover_bg
	end)

	widget.widget:connect_signal("mouse::leave", function(result)
		widget.widget.bg = beautiful.color.transparent
	end)

	return widget
end

return make
